"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.create = void 0;
const Utils = __importStar(require("../../utils"));
const createFormatSchemaToTypeNode = (factory, target) => {
    const typeNodes = target.output.type.map(value => {
        return factory.TypeReferenceNode.create({
            name: value,
        });
    });
    if (target.output.multiType === "allOf") {
        return factory.IntersectionTypeNode.create({
            typeNodes: typeNodes,
        });
    }
    return factory.UnionTypeNode.create({
        typeNodes: typeNodes,
    });
};
/**
 * ユーザーが利用できる各種変換オプション
 */
const create = (factory, options) => {
    const convertReservedWord = (word) => {
        if (["import", "export"].includes(word)) {
            return word + "_";
        }
        return word;
    };
    const convertString = (text) => {
        if (Utils.isAvailableVariableName(text)) {
            return text;
        }
        return text.replace(/-/g, "$").replace(/\//g, "$");
    };
    return {
        escapeOperationIdText: (operationId) => {
            return convertString(operationId);
        },
        escapeDeclarationText: (text) => {
            // console.log(`escapeDeclarationText: ${text}` + `-> ${convertReservedWord(convertString(text).replace(/\./g, "$"))}`.padStart(100, " "));
            return convertReservedWord(convertString(text).replace(/\./g, "$"));
        },
        escapeReferenceDeclarationText: (text) => {
            // console.log(`escapeDeclarationText3: ${text}` + `-> ${convertReservedWord(convertString(text))}`.padStart(100, " "));
            return convertReservedWord(convertString(text));
        },
        escapePropertySignatureName: (text) => {
            return Utils.escapeText(text);
        },
        escapeTypeReferenceNodeName: (text) => {
            return convertString(text);
        },
        generateResponseName: (operationId, statusCode) => {
            return Utils.responseName(convertString(operationId), statusCode);
        },
        generateArgumentParamsTypeDeclaration: (operationId) => {
            return Utils.argumentParamsTypeDeclaration(convertString(operationId));
        },
        generateRequestContentTypeName: (operationId) => {
            return Utils.requestContentType(convertString(operationId));
        },
        generateResponseContentTypeName: (operationId) => {
            return Utils.responseContentType(convertString(operationId));
        },
        generateParameterName: (operationId) => {
            return Utils.parameterName(convertString(operationId));
        },
        generateRequestBodyName: (operationId) => {
            return Utils.requestBodyName(convertString(operationId));
        },
        generateFunctionName: (operationId) => {
            return convertString(operationId);
        },
        convertFormatTypeNode: schema => {
            const formatConversions = options === null || options === void 0 ? void 0 : options.formatConversions;
            if (!formatConversions || formatConversions.length === 0) {
                return;
            }
            if (typeof schema === "boolean") {
                return;
            }
            if (!schema.format) {
                return;
            }
            const target = formatConversions.find(formatConvertion => formatConvertion.selector.format === schema.format);
            if (!target) {
                return;
            }
            return createFormatSchemaToTypeNode(factory, target);
        },
    };
};
exports.create = create;
//# sourceMappingURL=ConverterContext.js.map