"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateComment = exports.escapeIdentiferText = exports.isOnlyAlphabetText = void 0;
const os_1 = require("os");
const isOnlyAlphabetText = (text) => {
    return new RegExp(/^[a-zA-Z]+$/).test(text);
};
exports.isOnlyAlphabetText = isOnlyAlphabetText;
const escapeIdentiferText = (text) => {
    return text.replace(/-/g, "_");
};
exports.escapeIdentiferText = escapeIdentiferText;
const generateComment = (comment, deprecated) => {
    const excapedComment = comment
        .replace(/\*\//, "\\*\\\\/") // */  -> \*\/
        .replace(/\/\*/, "/\\\\*") // /*  -> \/\*
        .replace(/\*\/\*/, "\\*\\/\\*"); // */* -> \*\/\*
    const splitComments = deprecated ? ["@deprecated"].concat(excapedComment.split(/\r?\n/)) : excapedComment.split(/\r?\n/);
    const comments = splitComments.filter((comment, index) => {
        if (index === splitComments.length - 1 && comment === "") {
            return false;
        }
        return true;
    });
    if (comments.length === 1) {
        return {
            hasTrailingNewLine: true,
            value: "* " + comments.join("") + " ",
        };
    }
    return {
        hasTrailingNewLine: true,
        value: "*" + os_1.EOL + comments.map(comment => ` * ${comment}`).join(os_1.EOL) + os_1.EOL + " ",
    };
};
exports.generateComment = generateComment;
//# sourceMappingURL=utils.js.map