import ts from "typescript";
import { generateComment } from "./utils";
export const create = ({ factory }) => (params) => {
    const modifiers = [];
    if (params.private) {
        modifiers.push(factory.createModifier(ts.SyntaxKind.PrivateKeyword));
    }
    else {
        modifiers.push(factory.createModifier(ts.SyntaxKind.PublicKeyword));
    }
    if (params.async) {
        modifiers.push(factory.createModifier(ts.SyntaxKind.AsyncKeyword));
    }
    const node = factory.createMethodDeclaration(undefined, modifiers, undefined, factory.createIdentifier(params.name), undefined, params.typeParameters, params.parameters || [], params.type, params.body);
    if (params.comment) {
        const comment = generateComment(params.comment, params.deprecated);
        return ts.addSyntheticLeadingComment(node, ts.SyntaxKind.MultiLineCommentTrivia, comment.value, comment.hasTrailingNewLine);
    }
    return node;
};
export const make = (context) => {
    return {
        create: create(context),
    };
};
//# sourceMappingURL=MethodDeclaration.js.map